@@ -67,6 +67,11 @@ extern  SEXP    rotation2pole_test( SEXP u );
 extern  SEXP    dist2pgram_test( SEXP spoint, SEXP sv1, SEXP sv2, SEXP scenter, SEXP snormal );
 extern  SEXP    dist2surface( SEXP smatgen, SEXP sidxpair, SEXP scenter, SEXP snormal, SEXP spoint );
 extern  SEXP    clipquad( SEXP smatquad ) ;
+extern  SEXP    makeRawMap( SEXP sn, SEXP scount );
+extern  SEXP    getIndexRaw( SEXP smap, SEXP svec, SEXP scomp );
+extern  SEXP    computeVertices( SEXP smap, SEXP smatgen );
+extern  SEXP    getCodes( SEXP smap );
+extern  SEXP    deleteRawMap( SEXP smap );
 
 static R_CallMethodDef callMethods[]  = {
   {"dupAtomMatHash", (DL_FUNC) &dupAtomMatHash, 3},
@@ -113,7 +118,7 @@ static R_CallMethodDef callMethods[]  = {
   {"area_sphtri", (DL_FUNC) &area_sphtri, 3},
   {"linkingnumber", (DL_FUNC) &linkingnumber, 4},
   {"linkingnumber2", (DL_FUNC) &linkingnumber2, 2},
-  {"linkingnumber3", (DL_FUNC) &linkingnumber3, 4},  
+  {"linkingnumber3", (DL_FUNC) &linkingnumber3, 4},
   {"optimalcenter", (DL_FUNC) &optimalcenter, 2},
   {"extend_antipodal", (DL_FUNC) &extend_antipodal, 1},
   {"findpgram2D", (DL_FUNC) &findpgram2D, 4},
@@ -121,7 +126,12 @@ static R_CallMethodDef callMethods[]  = {
   {"rotation2pole_test", (DL_FUNC) &rotation2pole_test, 1},
   {"dist2pgram_test", (DL_FUNC) &dist2pgram_test, 5},
   {"dist2surface", (DL_FUNC) &dist2surface, 5},
-  {"clipquad", (DL_FUNC) &clipquad, 1},  
+  {"clipquad", (DL_FUNC) &clipquad, 1},
+  {"makeRawMap", (DL_FUNC) &makeRawMap, 2},
+  {"getIndexRaw", (DL_FUNC) &getIndexRaw, 3},
+  {"computeVertices", (DL_FUNC) &computeVertices, 2},
+  {"getCodes", (DL_FUNC) &getCodes, 1},
+  {"deleteRawMap", (DL_FUNC) &deleteRawMap, 1},
   {NULL, NULL, 0}
 };
 
